@@ -1,10 +1,10 @@
-########## S-function: tps.cov ##########
+########## R-function: tps.cov ##########
 
 # Evaluates the thin plate spline
 # covariance function for two dimensional
 # smoothing/kriging.
 
-# Last changed: 23 MAY 2001
+# Last changed: 25 OCT 2005
 
 tps.cov <- function(r,m=2,d=1)
 {     
@@ -16,18 +16,16 @@ tps.cov <- function(r,m=2,d=1)
 
     nzi <- (1:length(r))[r!=0]
 
-
     ans <- rep(0,length(r))
 
     if ((d+1)%%2!=0)    
-       ans[nzi] <- r[nzi]^(2*m-d)*log(abs(r[nzi]))     # d is even
+       ans[nzi] <- (abs(r[nzi]))^(2*m-d)*log(abs(r[nzi]))     # d is even
     else
-        ans[nzi] <- r[nzi]^(2*m-d)
-
+       ans[nzi] <- (abs(r[nzi]))^(2*m-d)
 
     if (num.col>1) ans <- matrix(ans,num.row,num.col)  # d is odd
 
     return(ans)
 }
 
-######### End of S-function tps.cov ########
+######### End of R-function tps.cov ########
